pub type Coef = Rational32;Expand description
The type of the coefficients in a linear expression.
Aliased Type
pub struct Coef { /* private fields */ }pub type Coef = Rational32;The type of the coefficients in a linear expression.
pub struct Coef { /* private fields */ }